==> GameboyVM-Project-0.06.zip: win32/DmaDlg.h <==
#if !defined(AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_)
#define AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DmaDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CDmaDlg _CAO

class CDmaDlg : public CDialog
{
// RXgNV
public:
	CDmaDlg(CWnd* pParent = NULL);   // W̃RXgN^
	void ShowDma();
	void ShowDmaChar();
	void OnOK();
	WORD DmaAdr;
	UINT t_num;

// _CAO f[^
	//{{AFX_DATA(CDmaDlg)
	enum { IDD = IDD_DMA_DIALOG };
	CScrollBar	m_scrBank;
	CScrollBar	m_scrDma;
	CString	m_txtDma;
	UINT	m_txtOffset;
	UINT	m_txtBank;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDmaDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDmaDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnClose();
	afx_msg void OnPaint();
	afx_msg void OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnButtonGo();
	afx_msg BOOL OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
	afx_msg void OnButtonPalette0();
	afx_msg void OnButtonPalette1();
	afx_msg void OnButtonPalette2();
	afx_msg void OnButtonPalette3();
	afx_msg void OnChangeEditOffset();
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnCheckEdit();
	afx_msg void OnButtonReset();
	afx_msg void OnButtonWrite();
	afx_msg void OnKillfocusEditBank();
	afx_msg void OnButtonSave();
	afx_msg void OnButtonSavebin();
	afx_msg void OnButtonLoadbin();
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnPalette0();
	afx_msg void OnPalette1();
	afx_msg void OnPalette2();
	afx_msg void OnPalette3();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_)

==> GameboyVM-Project-0.07.zip: win32/DmaDlg.h <==
#if !defined(AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_)
#define AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DmaDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CDmaDlg _CAO

class CDmaDlg : public CDialog
{
// RXgNV
public:
	CDmaDlg(CWnd* pParent = NULL);   // W̃RXgN^
	void ShowDma();
	void ShowDmaChar();
	void OnOK();
	WORD DmaAdr;
	UINT t_num;
	bool fLMouse;
	BYTE rsize;

// _CAO f[^
	//{{AFX_DATA(CDmaDlg)
	enum { IDD = IDD_DMA_DIALOG };
	CScrollBar	m_scrBank;
	CScrollBar	m_scrDma;
	CString	m_txtDma;
	UINT	m_txtOffset;
	UINT	m_txtBank;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDmaDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDmaDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnClose();
	afx_msg void OnPaint();
	afx_msg void OnVScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnButtonGo();
	afx_msg BOOL OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
	afx_msg void OnChangeEditOffset();
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnCheckEdit();
	afx_msg void OnButtonReset();
	afx_msg void OnButtonWrite();
	afx_msg void OnKillfocusEditBank();
	afx_msg void OnButtonSave();
	afx_msg void OnButtonSavebin();
	afx_msg void OnButtonLoadbin();
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnPalette0();
	afx_msg void OnPalette1();
	afx_msg void OnPalette2();
	afx_msg void OnPalette3();
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DMADLG_H__45FD72C1_5531_485C_8435_8917D6892386__INCLUDED_)
